VideoPlayerOptions class

VideoPlayerOptions can be optionally used to set additional player settings

Annotations

Constructors

VideoPlayerOptions({bool mixWithOthers = false, bool allowBackgroundPlayback = false, VideoPlayerWebOptions? webOptions, int? maxCacheSize, int? maxFileSize, bool enableCache = false})
Set additional optional player settings

Properties

allowBackgroundPlayback → bool
Set this to true to keep playing video in background, when app goes in background. The default value is false.
final
enableCache → bool
Whether caching is enabled. All parameters are best-effort, and not all platforms will support all options.
final
hashCode → int
The hash code for this object.
no setterinherited
maxCacheSize → int?
Will set the total size of the cache in bytes. null means that there is no cache enabled. 1 * 1024 * 1024 will be 1MB and it will automatically remove oldest used files if the size is reached out. Detection with whatever is set here.
final
maxFileSize → int?
Will set the size of a cache for one file (uri). Default maxFileSize is 0 (no cache enabled). 1 * 1024 * 1024 will be 1MB and it will automatically remove oldest used files if the size is reached out. Detection with whatever is set here.
final
mixWithOthers → bool
Set this to true to mix the video players audio with other audio sources. The default value is false
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webOptions → VideoPlayerWebOptions?
Additional web controls
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited